# Compass Api Client

#### Welcome to the DeFi API from [Compass Labs](https://www.compasslabs.ai)!

Our API allows you to interact and transact in DeFi with ease.

We help you construct your transactions via a **simple REST API**.  You maintain custody at all
times and **sign** all transactions **yourself**.

This Python package is automatically generated by the [OpenAPI
Generator](https://openapi-generator.tech) project:

- API version: 0.0.1
- Package version: 1.0.122
- Generator version: 7.13.0-SNAPSHOT
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage ### pip install

[PyPi org hosted](https://pypi.org/project/compass.api-client/) If the python package is hosted on a
repository, you can install directly using:

```sh pip install compass.api-client ```

Then import the package: ```python import compass.api_client ```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh python setup.py install --user ``` (or `sudo python setup.py install` to install the package
for all users)

Then import the package: ```python import compass.api_client ```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import compass.api_client from compass.api_client.rest import ApiException from pprint import pprint

# Defining the host is optional and defaults to https://api.compasslabs.ai # See configuration.py
for a list of all supported configuration parameters. configuration =
  compass.api_client.Configuration( host = "https://api.compasslabs.ai")

# Configure API key authorization: ApiKeyAuth configuration.api_key['ApiKeyAuth'] =
  os.environ["API_KEY"]

    # Uncomment below to setup prefix (e.g. Bearer) for API key, if needed #
    configuration.api_key_prefix['ApiKeyAuth'] = 'Bearer'

# Enter a context with an instance of the API client with
  compass.api_client.ApiClient(configuration) as api_client: # Create an instance of the API class
  api_instance = compass.api_client.AaveV3Api(api_client) aave_borrow_request =
    compass.api_client.AaveBorrowRequest() 

  try: # Borrow/Lend api_response = api_instance.borrow_v0_aave_borrow_post(aave_borrow_request)
  print("The response of AaveV3Api->borrow_v0_aave_borrow_post:\n") pprint(api_response) except
    ApiException as e: print("Exception when calling AaveV3Api->borrow_v0_aave_borrow_post: %s\n" %
    e)

```

## Documentation for API Endpoints

Examples and tutorials can be find in [tutorials](../tutorials/)

All URIs are relative to *https://api.compasslabs.ai*

Class | Method | HTTP request | Description ------------ | ------------- | ------------- |
------------- *AaveV3Api* |
[**borrow_v0_aave_borrow_post**](docs/AaveV3Api.md#borrow_v0_aave_borrow_post) | **POST**
/v0/aave/borrow | Borrow/Lend *AaveV3Api* |
[**get_asset_price_v0_aave_asset_price_get_post**](docs/AaveV3Api.md#get_asset_price_v0_aave_asset_price_get_post)
| **POST** /v0/aave/asset_price/get | Token prices *AaveV3Api* |
[**get_liquidity_change_v0_aave_liquidity_change_get_post**](docs/AaveV3Api.md#get_liquidity_change_v0_aave_liquidity_change_get_post)
| **POST** /v0/aave/liquidity/change/get | Liquidity index *AaveV3Api* |
[**get_user_position_per_token_v0_aave_user_position_per_token_get_post**](docs/AaveV3Api.md#get_user_position_per_token_v0_aave_user_position_per_token_get_post)
| **POST** /v0/aave/user_position_per_token/get | Positions - per token *AaveV3Api* |
[**get_user_position_summary_v0_aave_user_position_summary_get_post**](docs/AaveV3Api.md#get_user_position_summary_v0_aave_user_position_summary_get_post)
| **POST** /v0/aave/user_position_summary/get | Positions - total *AaveV3Api* |
[**repay_v0_aave_repay_post**](docs/AaveV3Api.md#repay_v0_aave_repay_post) | **POST** /v0/aave/repay
| Repay loans *AaveV3Api* |
[**supply_v0_aave_supply_post**](docs/AaveV3Api.md#supply_v0_aave_supply_post) | **POST**
/v0/aave/supply | Supply/Stake *AaveV3Api* |
[**withdraw_v0_aave_withdraw_post**](docs/AaveV3Api.md#withdraw_v0_aave_withdraw_post) | **POST**
/v0/aave/withdraw | Unstake *AerodromeBasicApi* |
[**process_request_v0_aerodrome_basic_liquidity_provision_add_liquidity_eth_post**](docs/AerodromeBasicApi.md#process_request_v0_aerodrome_basic_liquidity_provision_add_liquidity_eth_post)
| **POST** /v0/aerodrome_basic/liquidity_provision/add_liquidity_eth | Provide liquidity using WETH
*AerodromeBasicApi* |
[**process_request_v0_aerodrome_basic_liquidity_provision_add_liquidity_post**](docs/AerodromeBasicApi.md#process_request_v0_aerodrome_basic_liquidity_provision_add_liquidity_post)
| **POST** /v0/aerodrome_basic/liquidity_provision/add_liquidity | Provide liquidity
*AerodromeBasicApi* |
[**process_request_v0_aerodrome_basic_liquidity_provision_remove_liquidity_eth_post**](docs/AerodromeBasicApi.md#process_request_v0_aerodrome_basic_liquidity_provision_remove_liquidity_eth_post)
| **POST** /v0/aerodrome_basic/liquidity_provision/remove_liquidity_eth | Remove liquidity using
WETH *AerodromeBasicApi* |
[**process_request_v0_aerodrome_basic_liquidity_provision_remove_liquidity_post**](docs/AerodromeBasicApi.md#process_request_v0_aerodrome_basic_liquidity_provision_remove_liquidity_post)
| **POST** /v0/aerodrome_basic/liquidity_provision/remove_liquidity | Remove liquidity
*AerodromeBasicApi* |
[**process_request_v0_aerodrome_basic_swap_eth_for_token_post**](docs/AerodromeBasicApi.md#process_request_v0_aerodrome_basic_swap_eth_for_token_post)
| **POST** /v0/aerodrome_basic/swap/eth_for_token | Swap from ETH *AerodromeBasicApi* |
[**process_request_v0_aerodrome_basic_swap_token_for_eth_post**](docs/AerodromeBasicApi.md#process_request_v0_aerodrome_basic_swap_token_for_eth_post)
| **POST** /v0/aerodrome_basic/swap/token_for_eth | Swap to ETH *AerodromeBasicApi* |
[**process_request_v0_aerodrome_basic_swap_tokens_post**](docs/AerodromeBasicApi.md#process_request_v0_aerodrome_basic_swap_tokens_post)
| **POST** /v0/aerodrome_basic/swap/tokens | Swap *AerodromeSlipstreamApi* |
[**process_request_v0_aerodrome_slipstream_liquidity_provision_increase_post**](docs/AerodromeSlipstreamApi.md#process_request_v0_aerodrome_slipstream_liquidity_provision_increase_post)
| **POST** /v0/aerodrome_slipstream/liquidity_provision/increase | Increase an LP position
*AerodromeSlipstreamApi* |
[**process_request_v0_aerodrome_slipstream_liquidity_provision_mint_post**](docs/AerodromeSlipstreamApi.md#process_request_v0_aerodrome_slipstream_liquidity_provision_mint_post)
| **POST** /v0/aerodrome_slipstream/liquidity_provision/mint | Open a new LP position
*AerodromeSlipstreamApi* |
[**process_request_v0_aerodrome_slipstream_liquidity_provision_positions_get_post**](docs/AerodromeSlipstreamApi.md#process_request_v0_aerodrome_slipstream_liquidity_provision_positions_get_post)
| **POST** /v0/aerodrome_slipstream/liquidity_provision/positions/get | List LP positions
*AerodromeSlipstreamApi* |
[**process_request_v0_aerodrome_slipstream_liquidity_provision_withdraw_post**](docs/AerodromeSlipstreamApi.md#process_request_v0_aerodrome_slipstream_liquidity_provision_withdraw_post)
| **POST** /v0/aerodrome_slipstream/liquidity_provision/withdraw | Withdraw an LP position
*AerodromeSlipstreamApi* |
[**process_request_v0_aerodrome_slipstream_pool_price_get_post**](docs/AerodromeSlipstreamApi.md#process_request_v0_aerodrome_slipstream_pool_price_get_post)
| **POST** /v0/aerodrome_slipstream/pool_price/get | Pool price *AerodromeSlipstreamApi* |
[**process_request_v0_aerodrome_slipstream_swap_buy_exactly_post**](docs/AerodromeSlipstreamApi.md#process_request_v0_aerodrome_slipstream_swap_buy_exactly_post)
| **POST** /v0/aerodrome_slipstream/swap/buy_exactly | Swap - into specified amount
*AerodromeSlipstreamApi* |
[**process_request_v0_aerodrome_slipstream_swap_sell_exactly_post**](docs/AerodromeSlipstreamApi.md#process_request_v0_aerodrome_slipstream_swap_sell_exactly_post)
| **POST** /v0/aerodrome_slipstream/swap/sell_exactly | Swap - from specified amount *OthersApi* |
[**get_allowance_v0_generic_allowance_get_post**](docs/OthersApi.md#get_allowance_v0_generic_allowance_get_post)
| **POST** /v0/generic/allowance/get | Get allowance - Protocol *OthersApi* |
[**get_balance_v0_generic_balance_get_post**](docs/OthersApi.md#get_balance_v0_generic_balance_get_post)
| **POST** /v0/generic/balance/get | User token balance *OthersApi* |
[**get_ens_details_v0_generic_ens_get_post**](docs/OthersApi.md#get_ens_details_v0_generic_ens_get_post)
| **POST** /v0/generic/ens/get | Resolve ENS *OthersApi* |
[**get_portfolio_v0_generic_portfolio_get_post**](docs/OthersApi.md#get_portfolio_v0_generic_portfolio_get_post)
| **POST** /v0/generic/portfolio/get | List user portfolio *OthersApi* |
[**get_price_v0_generic_price_usd_get_post**](docs/OthersApi.md#get_price_v0_generic_price_usd_get_post)
| **POST** /v0/generic/price/usd/get | Token price *OthersApi* |
[**get_tokens_v0_generic_supported_tokens_get_post**](docs/OthersApi.md#get_tokens_v0_generic_supported_tokens_get_post)
| **POST** /v0/generic/supported_tokens/get | List supported tokens *OthersApi* |
[**set_allowance_v0_generic_allowance_set_post**](docs/OthersApi.md#set_allowance_v0_generic_allowance_set_post)
| **POST** /v0/generic/allowance/set | Set Allowance - Protocol *OthersApi* |
[**set_any_allowance_v0_generic_allowance_set_any_post**](docs/OthersApi.md#set_any_allowance_v0_generic_allowance_set_any_post)
| **POST** /v0/generic/allowance/set_any | Set Allowance - Token *OthersApi* |
[**transfer_erc20_v0_generic_transfer_erc20_post**](docs/OthersApi.md#transfer_erc20_v0_generic_transfer_erc20_post)
| **POST** /v0/generic/transfer/erc20 | Transfer Token *OthersApi* |
[**transfer_native_token_v0_generic_transfer_native_token_post**](docs/OthersApi.md#transfer_native_token_v0_generic_transfer_native_token_post)
| **POST** /v0/generic/transfer/native_token | Transfer ETH *OthersApi* |
[**unwrap_weth_v0_generic_unwrap_weth_post**](docs/OthersApi.md#unwrap_weth_v0_generic_unwrap_weth_post)
| **POST** /v0/generic/unwrap_weth | Unwrap WETH *OthersApi* |
[**visualize_portfolio_v0_generic_visualize_portfolio_get_post**](docs/OthersApi.md#visualize_portfolio_v0_generic_visualize_portfolio_get_post)
| **POST** /v0/generic/visualize_portfolio/get | Visualize user portfolio *OthersApi* |
[**wrap_eth_v0_generic_wrap_eth_post**](docs/OthersApi.md#wrap_eth_v0_generic_wrap_eth_post) |
**POST** /v0/generic/wrap_eth | Wrap ETH *UniswapV3Api* |
[**buy_exactly_v0_uniswap_swap_buy_exactly_post**](docs/UniswapV3Api.md#buy_exactly_v0_uniswap_swap_buy_exactly_post)
| **POST** /v0/uniswap/swap/buy_exactly | Buy exact amount *UniswapV3Api* |
[**get_buy_quote_v0_uniswap_quote_buy_exactly_get_post**](docs/UniswapV3Api.md#get_buy_quote_v0_uniswap_quote_buy_exactly_get_post)
| **POST** /v0/uniswap/quote/buy_exactly/get | Get quote - to specified amount *UniswapV3Api* |
[**get_pool_price_v0_uniswap_pool_price_get_post**](docs/UniswapV3Api.md#get_pool_price_v0_uniswap_pool_price_get_post)
| **POST** /v0/uniswap/pool_price/get | Pool price *UniswapV3Api* |
[**get_positions_v0_uniswap_liquidity_provision_positions_get_post**](docs/UniswapV3Api.md#get_positions_v0_uniswap_liquidity_provision_positions_get_post)
| **POST** /v0/uniswap/liquidity_provision/positions/get | List LP *UniswapV3Api* |
[**get_sell_quote_v0_uniswap_quote_sell_exactly_get_post**](docs/UniswapV3Api.md#get_sell_quote_v0_uniswap_quote_sell_exactly_get_post)
| **POST** /v0/uniswap/quote/sell_exactly/get | Get quote - from specified amount *UniswapV3Api* |
[**in_range_v0_uniswap_liquidity_provision_in_range_get_post**](docs/UniswapV3Api.md#in_range_v0_uniswap_liquidity_provision_in_range_get_post)
| **POST** /v0/uniswap/liquidity_provision/in_range/get | Check if LP is active. *UniswapV3Api* |
[**increase_liquidity_v0_uniswap_liquidity_provision_increase_post**](docs/UniswapV3Api.md#increase_liquidity_v0_uniswap_liquidity_provision_increase_post)
| **POST** /v0/uniswap/liquidity_provision/increase | Increase an LP position *UniswapV3Api* |
[**mint_v0_uniswap_liquidity_provision_mint_post**](docs/UniswapV3Api.md#mint_v0_uniswap_liquidity_provision_mint_post)
| **POST** /v0/uniswap/liquidity_provision/mint | Open a new LP position *UniswapV3Api* |
[**sell_exactly_v0_uniswap_swap_sell_exactly_post**](docs/UniswapV3Api.md#sell_exactly_v0_uniswap_swap_sell_exactly_post)
| **POST** /v0/uniswap/swap/sell_exactly | Sell exact amount *UniswapV3Api* |
[**withdraw_v0_uniswap_liquidity_provision_withdraw_post**](docs/UniswapV3Api.md#withdraw_v0_uniswap_liquidity_provision_withdraw_post)
| **POST** /v0/uniswap/liquidity_provision/withdraw | Withdraw an LP position


## Documentation For Models

- [AaveAssetPriceResponse](docs/AaveAssetPriceResponse.md)
- [AaveBorrowRequest](docs/AaveBorrowRequest.md)
- [AaveGetAssetPriceRequest](docs/AaveGetAssetPriceRequest.md)
- [AaveGetLiquidityChangeRequest](docs/AaveGetLiquidityChangeRequest.md)
- [AaveGetUserPositionPerTokenRequest](docs/AaveGetUserPositionPerTokenRequest.md)
- [AaveGetUserPositionSummaryRequest](docs/AaveGetUserPositionSummaryRequest.md)
- [AaveLiquidityChangeResponse](docs/AaveLiquidityChangeResponse.md)
- [AaveRepayRequest](docs/AaveRepayRequest.md)
- [AaveSupplyRequest](docs/AaveSupplyRequest.md)
- [AaveUserPositionPerTokenResponse](docs/AaveUserPositionPerTokenResponse.md)
- [AaveUserPositionSummaryResponse](docs/AaveUserPositionSummaryResponse.md)
- [AaveWithdrawRequest](docs/AaveWithdrawRequest.md)
- [AerodromeLPPositionsInfo](docs/AerodromeLPPositionsInfo.md)
- [AerodromeLiquidityProvisionCallData](docs/AerodromeLiquidityProvisionCallData.md)
- [AerodromeLiquidityProvisionEthCallData](docs/AerodromeLiquidityProvisionEthCallData.md)
- [AerodromePosition](docs/AerodromePosition.md)
- [AerodromeRemoveLiquidityCallData](docs/AerodromeRemoveLiquidityCallData.md)
- [AerodromeRemoveLiquidityEthCallData](docs/AerodromeRemoveLiquidityEthCallData.md)
- [AerodromeSlipstreamBuyExactlyCallData](docs/AerodromeSlipstreamBuyExactlyCallData.md)
- [AerodromeSlipstreamGetLiquidityProvisionPositions](docs/AerodromeSlipstreamGetLiquidityProvisionPositions.md)
- [AerodromeSlipstreamGetPoolPrice](docs/AerodromeSlipstreamGetPoolPrice.md)
- [AerodromeSlipstreamIncreaseLiquidityProvisionCallData](docs/AerodromeSlipstreamIncreaseLiquidityProvisionCallData.md)
- [AerodromeSlipstreamMintLiquidityProvisionCallData](docs/AerodromeSlipstreamMintLiquidityProvisionCallData.md)
- [AerodromeSlipstreamPoolPrice](docs/AerodromeSlipstreamPoolPrice.md)
- [AerodromeSlipstreamSellExactlyCallData](docs/AerodromeSlipstreamSellExactlyCallData.md)
- [AerodromeSlipstreamWithdrawLiquidityProvisionCallData](docs/AerodromeSlipstreamWithdrawLiquidityProvisionCallData.md)
- [AerodromeSwapEthForTokenCallData](docs/AerodromeSwapEthForTokenCallData.md)
- [AerodromeSwapTokenForEthCallData](docs/AerodromeSwapTokenForEthCallData.md)
- [AerodromeSwapTokensCallData](docs/AerodromeSwapTokensCallData.md)
- [AllowanceInfoResponse](docs/AllowanceInfoResponse.md)
- [Amount](docs/Amount.md)
- [Amount0Desired](docs/Amount0Desired.md)
- [Amount0Desired1](docs/Amount0Desired1.md)
- [Amount0Min](docs/Amount0Min.md)
- [Amount0Min1](docs/Amount0Min1.md)
- [Amount1](docs/Amount1.md)
- [Amount1Desired](docs/Amount1Desired.md)
- [Amount1Desired1](docs/Amount1Desired1.md)
- [Amount1Min](docs/Amount1Min.md)
- [Amount1Min1](docs/Amount1Min1.md)
- [Amount2](docs/Amount2.md)
- [Amount3](docs/Amount3.md)
- [Amount4](docs/Amount4.md)
- [Amount5](docs/Amount5.md)
- [Amount6](docs/Amount6.md)
- [Amount7](docs/Amount7.md)
- [Amount8](docs/Amount8.md)
- [AmountADesired](docs/AmountADesired.md)
- [AmountAMin](docs/AmountAMin.md)
- [AmountAMin1](docs/AmountAMin1.md)
- [AmountBDesired](docs/AmountBDesired.md)
- [AmountBMin](docs/AmountBMin.md)
- [AmountBMin1](docs/AmountBMin1.md)
- [AmountEthDesired](docs/AmountEthDesired.md)
- [AmountEthMin](docs/AmountEthMin.md)
- [AmountEthMin1](docs/AmountEthMin1.md)
- [AmountIn](docs/AmountIn.md)
- [AmountIn1](docs/AmountIn1.md)
- [AmountIn2](docs/AmountIn2.md)
- [AmountInMaximum](docs/AmountInMaximum.md)
- [AmountOut](docs/AmountOut.md)
- [AmountOutMin](docs/AmountOutMin.md)
- [AmountOutMin1](docs/AmountOutMin1.md)
- [AmountOutMinimum](docs/AmountOutMinimum.md)
- [AmountTokenDesired](docs/AmountTokenDesired.md)
- [AmountTokenMin](docs/AmountTokenMin.md)
- [AmountTokenMin1](docs/AmountTokenMin1.md)
- [BalanceInfoResponse](docs/BalanceInfoResponse.md)
- [BaseTransactionRequestAerodromeLiquidityProvisionCallData](docs/BaseTransactionRequestAerodromeLiquidityProvisionCallData.md)
- [BaseTransactionRequestAerodromeLiquidityProvisionEthCallData](docs/BaseTransactionRequestAerodromeLiquidityProvisionEthCallData.md)
- [BaseTransactionRequestAerodromeRemoveLiquidityCallData](docs/BaseTransactionRequestAerodromeRemoveLiquidityCallData.md)
- [BaseTransactionRequestAerodromeRemoveLiquidityEthCallData](docs/BaseTransactionRequestAerodromeRemoveLiquidityEthCallData.md)
- [BaseTransactionRequestAerodromeSlipstreamBuyExactlyCallData](docs/BaseTransactionRequestAerodromeSlipstreamBuyExactlyCallData.md)
- [BaseTransactionRequestAerodromeSlipstreamIncreaseLiquidityProvisionCallData](docs/BaseTransactionRequestAerodromeSlipstreamIncreaseLiquidityProvisionCallData.md)
- [BaseTransactionRequestAerodromeSlipstreamMintLiquidityProvisionCallData](docs/BaseTransactionRequestAerodromeSlipstreamMintLiquidityProvisionCallData.md)
- [BaseTransactionRequestAerodromeSlipstreamSellExactlyCallData](docs/BaseTransactionRequestAerodromeSlipstreamSellExactlyCallData.md)
- [BaseTransactionRequestAerodromeSlipstreamWithdrawLiquidityProvisionCallData](docs/BaseTransactionRequestAerodromeSlipstreamWithdrawLiquidityProvisionCallData.md)
- [BaseTransactionRequestAerodromeSwapEthForTokenCallData](docs/BaseTransactionRequestAerodromeSwapEthForTokenCallData.md)
- [BaseTransactionRequestAerodromeSwapTokenForEthCallData](docs/BaseTransactionRequestAerodromeSwapTokenForEthCallData.md)
- [BaseTransactionRequestAerodromeSwapTokensCallData](docs/BaseTransactionRequestAerodromeSwapTokensCallData.md)
- [Chain](docs/Chain.md)
- [ContractName](docs/ContractName.md)
- [EnsNameInfoResponse](docs/EnsNameInfoResponse.md)
- [FeeEnum](docs/FeeEnum.md)
- [GetEnsDetailsRequest](docs/GetEnsDetailsRequest.md)
- [GetErc20AllowanceRequest](docs/GetErc20AllowanceRequest.md)
- [GetErc20BalanceRequest](docs/GetErc20BalanceRequest.md)
- [HTTPValidationError](docs/HTTPValidationError.md)
- [Image](docs/Image.md)
- [IncreaseAllowanceAnyRequest](docs/IncreaseAllowanceAnyRequest.md)
- [IncreaseAllowanceRequest](docs/IncreaseAllowanceRequest.md)
- [InterestRateMode](docs/InterestRateMode.md)
- [Liquidity](docs/Liquidity.md)
- [PercentageForWithdrawal](docs/PercentageForWithdrawal.md)
- [Portfolio](docs/Portfolio.md)
- [PortfolioRequest](docs/PortfolioRequest.md)
- [PriceRequest](docs/PriceRequest.md)
- [PriceResponse](docs/PriceResponse.md)
- [Token](docs/Token.md)
- [TokenBalance](docs/TokenBalance.md)
- [TokenInfo](docs/TokenInfo.md)
- [TokensRequest](docs/TokensRequest.md)
- [TransferERC20Request](docs/TransferERC20Request.md)
- [TransferEthRequest](docs/TransferEthRequest.md)
- [UniswapBuyExactlyRequest](docs/UniswapBuyExactlyRequest.md)
- [UniswapBuyQuoteInfoResponse](docs/UniswapBuyQuoteInfoResponse.md)
- [UniswapCheckInRangeRequest](docs/UniswapCheckInRangeRequest.md)
- [UniswapCheckInRangeResponse](docs/UniswapCheckInRangeResponse.md)
- [UniswapGetBuyQuoteRequest](docs/UniswapGetBuyQuoteRequest.md)
- [UniswapGetLiquidityProvisionPositionsRequest](docs/UniswapGetLiquidityProvisionPositionsRequest.md)
- [UniswapGetPoolPriceRequest](docs/UniswapGetPoolPriceRequest.md)
- [UniswapGetSellQuoteRequest](docs/UniswapGetSellQuoteRequest.md)
- [UniswapIncreaseLiquidityProvision](docs/UniswapIncreaseLiquidityProvision.md)
- [UniswapLPPositionsInfoResponse](docs/UniswapLPPositionsInfoResponse.md)
- [UniswapMintLiquidityProvision](docs/UniswapMintLiquidityProvision.md)
- [UniswapPoolPriceResponse](docs/UniswapPoolPriceResponse.md)
- [UniswapPosition](docs/UniswapPosition.md)
- [UniswapSellExactlyRequest](docs/UniswapSellExactlyRequest.md)
- [UniswapSellQuoteInfoResponse](docs/UniswapSellQuoteInfoResponse.md)
- [UniswapWithdrawLiquidityProvision](docs/UniswapWithdrawLiquidityProvision.md)
- [UnsignedTransaction](docs/UnsignedTransaction.md)
- [UnwrapWethRequest](docs/UnwrapWethRequest.md)
- [ValidationError](docs/ValidationError.md)
- [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)
- [VisualizePortfolioRequest](docs/VisualizePortfolioRequest.md)
- [WrapEthRequest](docs/WrapEthRequest.md)


<a id="documentation-for-authorization"></a> ## Documentation For Authorization


Authentication schemes defined for the API: <a id="ApiKeyAuth"></a> ### ApiKeyAuth

- **Type**: API key
- **API key parameter name**: x-api-key
- **Location**: HTTP header


## Author

@CompassLabs


